@@ -99,6 +99,7 @@ _S(AUDIT_ANOM_LINK, "used-suspcious-link")
 //_S(AUDIT_INTEGRITY_HASH,"")
 //_S(AUDIT_INTEGRITY_PCR,"")
 //_S(AUDIT_INTEGRITY_RULE,"")
+//_S(AUDIT_INTEGRITY_EVM_XATTR,"")
 _S(AUDIT_KERNEL, "initialized-audit-subsystem")
 _S(AUDIT_ANOM_LOGIN_FAILURES, "failed-log-in-too-many-times-to")
 _S(AUDIT_ANOM_LOGIN_TIME, "attempted-log-in-during-unusual-hour-to")
@@ -144,6 +145,7 @@ _S(AUDIT_FS_RELABEL, "relabeled-filesystem")
 _S(AUDIT_USER_MAC_POLICY_LOAD, "loaded-mac-policy")
 _S(AUDIT_ROLE_MODIFY, "modified-role")
 _S(AUDIT_USER_MAC_CONFIG_CHANGE, "changed-mac-configuration")
+_S(AUDIT_USER_MAC_STATUS, "changed-selinux-enforcement-to")
 //_S(AUDIT_CRYPTO_TEST_USER, "")
 //_S(AUDIT_CRYPTO_PARAM_CHANGE_USER, "")
 _S(AUDIT_CRYPTO_LOGIN, "crypto-officer-logged-in")
