@@ -1,5 +1,5 @@
 /* arm_table.h --
- * Copyright 2009-10,2013-18 Red Hat Inc., Durham, North Carolina.
+ * Copyright 2009-10,2013-20 Red Hat Inc.
  * All Rights Reserved.
  *
  * This library is free software; you can redistribute it and/or
@@ -382,3 +382,18 @@ _S(395, "pkey_alloc")
 _S(396, "pkey_free")
 _S(397, "statx")
 _S(398, "rseq")
+_S(399, "io_pgetevents")
+_S(400, "migrate_pages")
+_S(401, "kexec_file_load")
+_S(424, "pidfd_send_signal")
+_S(425, "io_uring_setup")
+_S(426, "io_uring_enter")
+_S(427, "io_uring_register")
+_S(428, "open_tree")
+_S(429, "move_mount")
+_S(430, "fsopen")
+_S(431, "fsconfig")
+_S(432, "fsmount")
+_S(433, "fspick")
+_S(434, "pidfd_open")
+_S(435, "clone3")
