@@ -1,5 +1,5 @@
 /* i386_table.h --
- * Copyright 2005-17 Red Hat Inc., Durham, North Carolina.
+ * Copyright 2005-20 Red Hat Inc.
  * All Rights Reserved.
  *
  * This library is free software; you can redistribute it and/or
@@ -340,7 +340,7 @@ _S(318, "getcpu")
 _S(319, "epoll_pwait")
 _S(320, "utimensat")
 _S(321, "signalfd")
-_S(322, "timerfd")
+_S(322, "timerfd_create")
 _S(323, "eventfd")
 _S(324, "fallocate")
 _S(325, "timerfd_settime")
@@ -405,3 +405,46 @@ _S(383, "statx")
 _S(384, "arch_prctl")
 _S(385, "io_pgetevents")
 _S(386, "rseq")
+_S(393, "semget")
+_S(394, "semctl")
+_S(395, "shmget")
+_S(396, "shmctl")
+_S(397, "shmat")
+_S(398, "shmdt")
+_S(399, "msgget")
+_S(400, "msgsnd")
+_S(401, "msgrcv")
+_S(402, "msgctl")
+_S(403, "clock_gettime64")
+_S(404, "clock_settime64")
+_S(405, "clock_adjtime64")
+_S(406, "clock_getres_time64")
+_S(407, "clock_nanosleep_time64")
+_S(408, "timer_gettime64")
+_S(409, "timer_settime64")
+_S(410, "timerfd_gettime64")
+_S(411, "timerfd_settime64")
+_S(412, "utimensat_time64")
+_S(413, "pselect6_time64")
+_S(414, "ppoll_time64")
+_S(416, "io_pgetevents_time64")
+_S(417, "recvmmsg_time64")
+_S(418, "mq_timedsend_time64")
+_S(419, "mq_timedreceive_time64")
+_S(420, "semtimedop_time64")
+_S(421, "rt_sigtimedwait_time64")
+_S(422, "futex_time64")
+_S(423, "sched_rr_get_interval64")
+_S(424, "pidfd_send_signal")
+_S(425, "io_uring_setup")
+_S(426, "io_uring_enter")
+_S(427, "io_uring_register")
+_S(428, "open_tree")
+_S(429, "move_mount")
+_S(430, "fsopen")
+_S(431, "fsconfig")
+_S(432, "fsmount")
+_S(433, "fspick")
+_S(434, "pidfd_open")
+_S(435, "clone3")
+
