@@ -123,6 +123,10 @@ _S(AUDIT_PROCTITLE,                  "PROCTITLE"                     )
 _S(AUDIT_FEATURE_CHANGE,             "FEATURE_CHANGE"                )
 _S(AUDIT_KERN_MODULE,                "KERN_MODULE"                   )
 _S(AUDIT_FANOTIFY,                   "FANOTIFY"                      )
+_S(AUDIT_TIME_INJOFFSET,             "TIME_INJOFFSET"                )
+_S(AUDIT_TIME_ADJNTPVAL,             "TIME_ADJNTPVAL"                )
+_S(AUDIT_BPF,                        "BPF"                           )
+_S(AUDIT_EVENT_LISTENER,             "EVENT_LISTENER"                )
 _S(AUDIT_AVC,                        "AVC"                           )
 _S(AUDIT_SELINUX_ERR,                "SELINUX_ERR"                   )
 _S(AUDIT_AVC_PATH,                   "AVC_PATH"                      )
@@ -141,15 +145,19 @@ _S(AUDIT_MAC_IPSEC_DELSPD,           "MAC_IPSEC_DELSPD"              )
 _S(AUDIT_MAC_IPSEC_EVENT,            "MAC_IPSEC_EVENT"               )
 _S(AUDIT_MAC_UNLBL_STCADD,           "MAC_UNLBL_STCADD"              )
 _S(AUDIT_MAC_UNLBL_STCDEL,           "MAC_UNLBL_STCDEL"              )
+_S(AUDIT_MAC_CALIPSO_ADD,            "MAC_CALIPSO_ADD"               )
+_S(AUDIT_MAC_CALIPSO_DEL,            "MAC_CALIPSO_DEL"               )
 _S(AUDIT_ANOM_PROMISCUOUS,           "ANOM_PROMISCUOUS"              )
 _S(AUDIT_ANOM_ABEND,                 "ANOM_ABEND"                    )
 _S(AUDIT_ANOM_LINK,                  "ANOM_LINK"                     )
+_S(AUDIT_ANOM_CREAT,                 "ANOM_CREAT"                    )
 _S(AUDIT_INTEGRITY_DATA,             "INTEGRITY_DATA"                )
 _S(AUDIT_INTEGRITY_METADATA,         "INTEGRITY_METADATA"            )
 _S(AUDIT_INTEGRITY_STATUS,           "INTEGRITY_STATUS"              )
 _S(AUDIT_INTEGRITY_HASH,             "INTEGRITY_HASH"                )
 _S(AUDIT_INTEGRITY_PCR,              "INTEGRITY_PCR"                 )
 _S(AUDIT_INTEGRITY_RULE,             "INTEGRITY_RULE"                )
+_S(AUDIT_INTEGRITY_EVM_XATTR,        "INTEGRITY_EVM_XATTR"           )
 
 #ifdef WITH_APPARMOR
 _S(AUDIT_AA,                         "APPARMOR"                      )
@@ -208,6 +216,7 @@ _S(AUDIT_FS_RELABEL,                 "FS_RELABEL"                    )
 _S(AUDIT_USER_MAC_POLICY_LOAD,       "USER_MAC_POLICY_LOAD"          )
 _S(AUDIT_ROLE_MODIFY,                "ROLE_MODIFY"                   )
 _S(AUDIT_USER_MAC_CONFIG_CHANGE,     "USER_MAC_CONFIG_CHANGE"        )
+_S(AUDIT_USER_MAC_STATUS,            "USER_MAC_STATUS"               )
 _S(AUDIT_CRYPTO_TEST_USER,           "CRYPTO_TEST_USER"              )
 _S(AUDIT_CRYPTO_PARAM_CHANGE_USER,   "CRYPTO_PARAM_CHANGE_USER"      )
 _S(AUDIT_CRYPTO_LOGIN,               "CRYPTO_LOGIN"                  )
