@@ -1,6 +1,6 @@
 /*
- * aureport.c - main file for aureport utility 
- * Copyright 2005-08, 2010,11,2013 Red Hat Inc., Durham, North Carolina.
+ * aureport.c - main file for aureport utility
+ * Copyright 2005-08, 2010,11,2013,2020 Red Hat
  * All Rights Reserved.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -42,6 +42,7 @@
 #include "ausearch-lol.h"
 #include "ausearch-lookup.h"
 #include "auparse-idata.h"
+#include "ausearch-parse.h"
 
 
 extern event very_first_event;
@@ -127,10 +128,11 @@ int main(int argc, char *argv[])
 		destroy_counters();
 		aulookup_destroy_uid_list();
 		return 1;
-	} else 
+	} else
 		print_wrap_up();
 	destroy_counters();
 	aulookup_destroy_uid_list();
+	lookup_uid_destroy_list();
 	free(user_file);
 	return 0;
 }
@@ -139,7 +141,8 @@ static int process_logs(void)
 {
 	struct daemon_conf config;
 	char *filename;
-	int len, num = 0;
+	size_t len;
+	int num = 0;
 
 	if (user_file && userfile_is_dir) {
 		char dirname[MAXPATHLEN];
@@ -154,7 +157,7 @@ static int process_logs(void)
 		fprintf(stderr, "NOTE - using logs in %s\n", config.log_file);
 	} else {
 		/* Load config so we know where logs are */
-       		if (load_config(&config, TEST_SEARCH))
+		if (load_config(&config, TEST_SEARCH))
 			fprintf(stderr, "NOTE - using built-in logs: %s\n",
 				config.log_file);
 	}
