@@ -1,6 +1,6 @@
 /*
 * ausearch-lol.c - linked list of linked lists library
-* Copyright (c) 2008,2010,2014,2016 Red Hat Inc., Durham, North Carolina.
+* Copyright (c) 2008,2010,2014,2016,2019 Red Hat Inc., Durham, North Carolina.
 * All Rights Reserved. 
 *
 * This software may be freely redistributed and/or modified under the
@@ -29,7 +29,7 @@
 #include <stdio.h>
 #include "ausearch-common.h"
 #include "auditd-config.h"
-#include "private.h"
+#include "common.h"
 
 #define ARRAY_LIMIT 80
 static int ready = 0;
@@ -152,6 +152,16 @@ static int compare_event_time(event *e1, event *e2)
 	return 0;
 }
 
+#ifndef HAVE_STRNDUPA
+static inline char *strndupa(const char *old, size_t n)
+{
+	size_t len = strnlen(old, n);
+	char *tmp = alloca(len + 1);
+	tmp[len] = 0;
+	return memcpy(tmp, old, len);
+}
+#endif
+
 /*
  * This function will look at the line and pick out pieces of it.
  */
@@ -203,6 +213,12 @@ static int extract_timestamp(const char *b, event *e)
 					}
 					return 0;
 				} else {
+					// If no start time, any event is 1st
+					if (very_first_event.sec == 0 &&
+							start_time == 0) {
+						very_first_event.sec = e->sec;
+						very_first_event.milli = e->milli;
+					}
 					if (tnode)
 						e->node = strdup(tnode);
 					e->type = audit_name_to_msg_type(ttype);
@@ -306,6 +322,14 @@ int lol_add_record(lol *lo, char *buff)
 			}
 		}
 	}
+
+	// Eat standalone EOE, main event was already marked complete
+	if (e.type == AUDIT_EOE) {
+		free((char *)e.node);
+		free(n.message);
+		return 0;
+	}
+
 	// Create new event and fill it in
 	l = malloc(sizeof(llist));
 	list_create(l);
