@@ -1,6 +1,6 @@
 /*
 * ausearch-parse.c - Extract interesting fields and check for match
-* Copyright (c) 2005-08,2011,2013-14,2018 Red Hat Inc., Durham, North Carolina.
+* Copyright (c) 2005-08,2011,2013-14,2018-20 Red Hat
 * Copyright (c) 2011 IBM Corp. 
 * All Rights Reserved. 
 *
@@ -39,6 +39,7 @@
 #include "ausearch-lookup.h"
 #include "ausearch-parse.h"
 #include "auparse-idata.h"
+#include "ausearch-nvpair.h"
 
 #define NAME_OFFSET 28
 static const char key_sep[2] = { AUDIT_KEY_SEPARATOR, 0 };
@@ -49,7 +50,7 @@ static int parse_dir(const lnode *n, search_items *s);
 static int common_path_parser(search_items *s, char *path);
 static int avc_parse_path(const lnode *n, search_items *s);
 static int parse_path(const lnode *n, search_items *s);
-static int parse_user(const lnode *n, search_items *s);
+static int parse_user(const lnode *n, search_items *s, anode *avc);
 static int parse_obj(const lnode *n, search_items *s);
 static int parse_login(const lnode *n, search_items *s);
 static int parse_daemon1(const lnode *n, search_items *s);
@@ -105,7 +106,7 @@ int extract_search_items(llist *l)
 			case AUDIT_FIRST_USER_MSG...AUDIT_USER_END:
 			case AUDIT_USER_CHAUTHTOK...AUDIT_LAST_USER_MSG:
 			case AUDIT_FIRST_USER_MSG2...AUDIT_LAST_USER_MSG2:
-				ret = parse_user(n, s);
+				ret = parse_user(n, s, NULL);
 				break;
 			case AUDIT_SOCKADDR:
 				ret = parse_sockaddr(n, s);
@@ -173,7 +174,7 @@ int extract_search_items(llist *l)
 			case AUDIT_MMAP:
 			case AUDIT_NETFILTER_CFG:
 			case AUDIT_PROCTITLE:
-			case AUDIT_KERN_MODULE:
+			case AUDIT_REPLACE...AUDIT_BPF:
 				// Nothing to parse
 				break;
 			case AUDIT_TTY:
@@ -198,6 +199,8 @@ int extract_search_items(llist *l)
 /*
  * returns malloc'ed buffer on success and NULL on failure
  */
+static nvlist uid_nvl;
+static int uid_list_created=0;
 static const char *lookup_uid(const char *field, uid_t uid)
 {
 	const char *value;
@@ -208,15 +211,38 @@ static const char *lookup_uid(const char *field, uid_t uid)
 		return strdup("root");
 	else if (uid == -1)
 		return strdup("unset");
-	else {
+
+	if (uid_list_created == 0) {
+		nvlist_create(&uid_nvl);
+		nvlist_clear(&uid_nvl);
+		uid_list_created = 1;
+	}
+
+	if (nvlist_find_val(&uid_nvl, uid)) {
+		return strdup(uid_nvl.cur->name);
+	} else {
 		struct passwd *pw;
 		pw = getpwuid(uid);
-		if (pw)
+		if (pw) {
+			nvnode nv;
+			nv.name = strdup(pw->pw_name);
+			nv.val = uid;
+			nvlist_append(&uid_nvl, &nv);
 			return strdup(pw->pw_name);
+		}
 	}
 	return NULL;
 }
 
+void lookup_uid_destroy_list(void)
+{
+	if (uid_list_created == 0)
+		return;
+
+	nvlist_clear(&uid_nvl);
+	uid_list_created = 0;
+}
+
 static int parse_task_info(lnode *n, search_items *s)
 {
 	char *ptr, *str, *term;
@@ -830,7 +856,7 @@ static int parse_obj(const lnode *n, search_items *s)
 	return 0;
 }
 
-static int parse_user(const lnode *n, search_items *s)
+static int parse_user(const lnode *n, search_items *s, anode *avc)
 {
 	char *ptr, *str, *term, saved, *mptr;
 
@@ -915,7 +941,10 @@ static int parse_user(const lnode *n, search_items *s)
 			if (term == NULL)
 				return 12;
 			*term = 0;
-			if (audit_avc_init(s) == 0) {
+			if (avc) {
+				avc->scontext = strdup(str);
+				*term = ' ';
+			} else if (audit_avc_init(s) == 0) {
 				anode an;
 
 				anode_init(&an);
@@ -926,6 +955,33 @@ static int parse_user(const lnode *n, search_items *s)
 				return 13;
 		}
 	}
+	// optionally get tcontext
+	if (avc && event_object) {
+		// USER_AVC tcontext
+		str = strstr(term, "tcontext=");
+		if (str != NULL) {
+			str += 9;
+			term = strchr(str, ' ');
+			if (term) {
+				*term = 0;
+				avc->tcontext = strdup(str);
+				*term = ' ';
+			} else
+				term = str;
+		}
+		// Grab tclass if it exists
+		str = strstr(term, "tclass=");
+		if (str) {
+			str += 7;
+			term = strchr(str, ' ');
+			if (term) {
+				*term = 0;
+				avc->avc_class = strdup(str);
+				*term = ' ';
+			} else
+				term = str;
+		}
+	}
 	// optionally get gid
 	if (event_gid != -1) {
 		if (n->type == AUDIT_ADD_GROUP || n->type == AUDIT_DEL_GROUP ||
@@ -1567,9 +1623,9 @@ static int parse_daemon2(const lnode *n, search_items *s)
 	}
 
 	if (event_success != S_UNSET) {
-		char *str = strstr(term, "res=");
+		str = strstr(term, "res=");
 		if (str) {
-			char *ptr, *term, saved;
+			char *ptr;
 
 			ptr = term = str + 4;
 			while (isalpha(*term))
@@ -1880,7 +1936,7 @@ static int parse_avc(const lnode *n, search_items *s)
 other_avc:
 	// User AVC's are not formatted like a kernel AVC
 	if (n->type == AUDIT_USER_AVC) {
-		rc = parse_user(n, s);
+		rc = parse_user(n, s, &an);
 		if (rc > 20)
 			rc = 0;
 		if (audit_avc_init(s) == 0) {
